"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.setStorageSync = exports.setStorage = exports.revokeBufferURL = exports.removeStorageSync = exports.removeStorage = exports.getStorageSync = exports.getStorageInfoSync = exports.getStorageInfo = exports.getStorage = exports.createBufferURL = exports.clearStorageSync = exports.clearStorage = void 0;
var _typeof2 = _interopRequireDefault(require("@babel/runtime/helpers/typeof"));
var _mpromisify = _interopRequireDefault(require("mpromisify"));
var _util = require("./_util");
var setStorageSyncInternal = function setStorageSyncInternal(key, data) {
  if (typeof key !== 'string') {
    throw new Error("key should be String instead of ".concat((0, _typeof2.default)(key), "."));
  }
  localStorage.setItem(key, JSON.stringify(data));
};

/**
 * 将数据存储在本地缓存中指定的 key 中。如果之前存在同名 key，会覆盖掉原来该 key 对应的内容。这是一个同步接口。
 */
var setStorageSync = exports.setStorageSync = _util.limited._void('setStorageSync', setStorageSyncInternal);
var setStorageInternal = function setStorageInternal(_ref) {
  var key = _ref.key,
    data = _ref.data,
    success = _ref.success,
    fail = _ref.fail,
    complete = _ref.complete;
  try {
    setStorageSync(key, data);
    success === null || success === void 0 || success();
  } catch (err) {
    fail === null || fail === void 0 || fail({
      errMsg: err.message
    });
  }
  complete === null || complete === void 0 || complete();
};

/**
 * 将数据存储在本地缓存中指定的 key 中，会覆盖掉原来该 key 对应的内容。
 */
var setStorage = exports.setStorage = (0, _mpromisify.default)(_util.limited.async('setStorage', setStorageInternal));

/**
 * 根据 URL 销毁存在内存中的数据
 */
var revokeBufferURL = exports.revokeBufferURL = _util.unsupported._void('revokeBufferURL');
var removeStorageSyncInternal = function removeStorageSyncInternal(key) {
  if (typeof key !== 'string') {
    throw new Error("key should be String instead of ".concat((0, _typeof2.default)(key), "."));
  }
  localStorage.removeItem(key);
};

/**
 * 从本地缓存中同步移除指定 key。
 */
var removeStorageSync = exports.removeStorageSync = _util.limited._void('removeStorageSync', removeStorageSyncInternal);
var removeStorageInternal = function removeStorageInternal(_ref2) {
  var key = _ref2.key,
    success = _ref2.success,
    fail = _ref2.fail,
    complete = _ref2.complete;
  try {
    removeStorageSync(key);
    success === null || success === void 0 || success();
  } catch (err) {
    fail === null || fail === void 0 || fail({
      errMsg: err.message
    });
  }
  complete === null || complete === void 0 || complete();
};

/**
 * 从本地缓存中同步移除指定 key。
 */
var removeStorage = exports.removeStorage = (0, _mpromisify.default)(_util.limited.async('removeStorage', removeStorageInternal));
var getStorageSyncInternal = function getStorageSyncInternal(key) {
  if (typeof key !== 'string') {
    throw new Error("key should be String instead of ".concat((0, _typeof2.default)(key), "."));
  }
  var json = localStorage.getItem(key);
  if (!json) {
    return '';
  }
  try {
    return JSON.parse(json);
  } catch (_unused) {}
  return '';
};

/**
 * 从本地缓存中同步移除指定 key。
 */
var getStorageSync = exports.getStorageSync = _util.limited.never('getStorageSync', getStorageSyncInternal);
var getStorageInternal = function getStorageInternal(_ref3) {
  var key = _ref3.key,
    success = _ref3.success,
    fail = _ref3.fail,
    complete = _ref3.complete;
  try {
    var data = getStorageSync(key);
    success === null || success === void 0 || success({
      data: data
    });
  } catch (err) {
    fail === null || fail === void 0 || fail({
      errMsg: err.message
    });
  }
  complete === null || complete === void 0 || complete();
};

/**
 * 从本地缓存中同步移除指定 key。
 */
var getStorage = exports.getStorage = (0, _mpromisify.default)(_util.limited.async('getStorage', getStorageInternal));
var getStorageInfoSyncInternal = function getStorageInfoSyncInternal() {
  var keys = [];
  var currentSize = 0;
  for (var key in localStorage) {
    keys.push(key);
    var value = localStorage.getItem(key);
    if (value != null) {
      currentSize += key.length + value.length;
    }
  }
  return {
    keys: keys,
    limitSize: Number.MAX_VALUE,
    currentSize: Math.ceil(currentSize * 2 / 1024)
  };
};

/**
 * 同步获取当前 storage 的相关信息。
 */
var getStorageInfoSync = exports.getStorageInfoSync = _util.limited.never('getStorageInfoSync', getStorageInfoSyncInternal);
var getStorageInfoInternal = function getStorageInfoInternal() {
  var _ref4 = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {},
    success = _ref4.success,
    fail = _ref4.fail,
    complete = _ref4.complete;
  try {
    var data = getStorageInfoSync();
    success === null || success === void 0 || success({
      data: data
    });
  } catch (err) {
    fail === null || fail === void 0 || fail({
      errMsg: err.message
    });
  }
  complete === null || complete === void 0 || complete();
};

/**
 * 获取当前 storage 的相关信息。
 */
var getStorageInfo = exports.getStorageInfo = (0, _mpromisify.default)(_util.limited.async('getStorageInfo', getStorageInfoInternal));

/**
 * 根据传入的 buffer 创建一个唯一的 URL 存在内存中。
 */
var createBufferURL = exports.createBufferURL = _util.unsupported._void('createBufferURL');
var clearStorageSyncInternal = function clearStorageSyncInternal() {
  localStorage.clear();
};

/**
 * 同步清理本地数据缓存。
 */
var clearStorageSync = exports.clearStorageSync = _util.limited._void('clearStorageSync', clearStorageSyncInternal);

/**
 * 清理本地数据缓存。
 */
var clearStorageInternal = function clearStorageInternal(_ref5) {
  var success = _ref5.success,
    complete = _ref5.complete;
  clearStorageSync();
  success === null || success === void 0 || success();
  complete === null || complete === void 0 || complete();
};
var clearStorage = exports.clearStorage = (0, _mpromisify.default)(_util.limited.async('clearStorage', clearStorageInternal));